import argparse
import sys
import json

from pyatome import AtomeClient


def main():
    """Main function"""
    parser = argparse.ArgumentParser()
    parser.add_argument('-u', '--username',
                        required=True, help='Atome username')
    parser.add_argument('-p', '--password',
                        required=True, help='Password')
    parser.add_argument('action', type=str,
                        default='live', help='Action [live/data]')
    args = parser.parse_args()

    client = AtomeClient(args.username, args.password)

    try:
        client.login()
        if args.action == 'live':
            print(json.dumps(client.get_live(), indent=2))
        else:
            print("Action not implemented. Please use 'live' as an action.")

    except BaseException as exp:
        print(exp)
        return 1
    finally:
        client.close_session()

if __name__ == '__main__':
    sys.exit(main())





from __future__ import print_function
from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand
import io
import codecs
import os
import sys


here = os.path.abspath(os.path.dirname(__file__))

def read(*filenames, **kwargs):
    encoding = kwargs.get('encoding', 'utf-8')
    sep = kwargs.get('sep', '\n')
    buf = []
    for filename in filenames:
        with io.open(filename, encoding=encoding) as f:
            buf.append(f.read())
    return sep.join(buf)

# long_description = read('README.txt', 'CHANGES.txt')
long_description = read('README.md')

class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        import pytest
        errcode = pytest.main(self.test_args)
        sys.exit(errcode)

setup(
    name='pyAtome',
    version="0.0.3",
    url='http://github.com/baqs/pyAtome/',
    license='Apache Software License',
    author='Pierre Ourdouille',
    tests_require=['pytest',
                    'requests_mock'
                    ],
    install_requires=['simplejson',
                    'requests',
                    'fake_useragent',
                    ],
    cmdclass={'test': PyTest},
    author_email='baqs@users.github.com',
    description='Get your energy consumption from Atome Linky device',
    long_description=long_description,
    packages=['pyatome'],
    include_package_data=True,
    platforms='any',
    test_suite='pyAtome.test.test_pyatome',
    classifiers = [
        'Programming Language :: Python',
        'Development Status :: 4 - Beta',
        'Natural Language :: English',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        ],
    entry_points={
        'console_scripts': [
            'pyatome = pyatome.__main__:main'
        ]
    },
    extras_require={
        'testing': ['pytest'],
    }
)



import json
import simplejson
# import pickle
# from dateutil.relativedelta import relativedelta
import requests
from fake_useragent import UserAgent


# ATOME_COOKIE = "atome_cookies.pickle"
# ATOME_USER_ID = "atome_user_id.pickle"
# ATOME_USER_REFERENCE = "atome_user_reference.pickle"


COOKIE_NAME = "PHPSESSID"
API_BASE_URI = "https://esoftlink.esoftthings.com"
API_ENDPOINT_LOGIN = "/api/user/login.json"
API_ENDPOINT_LIVE = "/measure/live.json"
LOGIN_URL = API_BASE_URI + API_ENDPOINT_LOGIN

DEFAULT_TIMEOUT = 10

# LOGIN_URL = "https://espace-client-connexion.enedis.fr/auth/UI/Login"
# HOST = "https://espace-client-particuliers.enedis.fr/group/espace-particuliers"
# DATA_URL = "{}/suivi-de-consommation".format(HOST)

# REQ_PART = "lincspartdisplaycdc_WAR_lincspartcdcportlet"

# HOURLY = "hourly"
# DAILY = "daily"
# MONTHLY = "monthly"
# YEARLY = "yearly"


# _DELTA = 'delta'
# _FORMAT = 'format'
# _RESSOURCE = 'ressource'
# _DURATION = 'duration'
# _MAP = {
#     _DELTA: {HOURLY: 'hours', DAILY: 'days', MONTHLY: 'months', YEARLY: 'years'},
#     _FORMAT: {HOURLY: "%H:%M", DAILY: "%d %b", MONTHLY: "%b", YEARLY: "%Y"},
#     _RESSOURCE: {HOURLY: 'urlCdcHeure', DAILY: 'urlCdcJour', MONTHLY: 'urlCdcMois', YEARLY: 'urlCdcAn'},
#     _DURATION: {HOURLY: 24, DAILY: 30, MONTHLY: 12, YEARLY: None}
# }


class PyAtomeError(Exception):
    pass


class AtomeClient(object):
    def __init__(self, username, password, session=None, timeout=None):
        """Initialize the client object."""
        self.username = username
        self.password = password
        self._user_id = None
        self._user_reference = None
        self._session = session
        self._data = {}
        self._timeout = timeout

    def login(self):
        """Set http session."""
        if self._session is None:
            self._session = requests.session()
            # adding fake user-agent header
            self._session.headers.update({'User-agent': str(UserAgent().random)})
        return self._login()

    def _login(self):
        """Login to Atome's API."""
        payload = {"email": self.username, "plainPassword": self.password}

        try:
            req = self._session.post(LOGIN_URL,
                               json=payload,
                               headers={"content-type": "application/json"},
                               timeout=self._timeout)
        except OSError:
            raise PyAtomeError("Can not login to API")
        if "PHPSESSID" not in self._session.cookies:
            raise PyAtomeError("Login error: Please check your username/password." + str(self._session.cookies))
        response_json = req.json()

        user_id = str(response_json["id"])
        user_reference = response_json["subscriptions"][0]["reference"]

        self._user_id = user_id
        self._user_reference = user_reference

        return True

    def _get_live(self):
        """Get data."""

        live_url = (
            API_BASE_URI
            + "/api/subscription/"
            + self._user_id
            + "/"
            + self._user_reference
            + API_ENDPOINT_LIVE
        )
        try:
            req = self._session.get(live_url,
                                    timeout=self._timeout)

        except OSError as e:
            raise PyAtomeError("Could not access Atome's API: " + str(e))

        if req.text is "":
            raise PyAtomeError("No data")

        try:
            json_output = req.json()
        except (OSError, json.decoder.JSONDecodeError, simplejson.errors.JSONDecodeError) as e:
            raise PyAtomeError("Impossible to decode response: " + str(e) + "\nResponse was: " + str(req.text))

        return json_output
        

    def get_live(self):
        """Get current data."""
        # return {"live": self._get_live}
        return self._get_live()

    def close_session(self):
        """Close current session."""
        self._session.close()
        self._session = None

